# Auto-DLP
A simple command-line utility for automating the process of downloading songs using yt-dlp and sorting them into folders. Can also push files to android devices.

The philosophy of this tool is to download songs and lay them out beautifully in the filesystem, this means that there are a lot of features to get the names of files, folders, etc. correct.

## Getting Started
Use ```pipx install auto-dlp``` to install the command directly or use
```pip install auto-dlp``` to install the module and run it using ```<Your python installation> -m auto_dlp```.
```Your python installation``` is usually one of ```python```, ```python3``` or ```py```.

In the command line try ```auto-dlp -h```. If this runs without an error, you have successfully installed the tool.

Now choose a directory in which you would like your music to be stored, there run the command ```auto-dlp --create-ex```